@@ -1,4 +1,5 @@
 pub mod char_types;
+pub mod cstr;
 pub mod def;
 pub mod float_types;
 pub mod int_types;
@@ -8,7 +9,10 @@ pub mod pointer;
 pub mod range;
 pub mod slice;
 pub mod str;
-use self::def::NSTDBool;
+use self::def::{NSTDAny, NSTDBool};
+
+/// A null pointer value.
+pub const NSTD_CORE_NULL: NSTDAny = core::ptr::null_mut();
 
 /// Terminates the program in an abnormal fashion.
 #[inline]
